==> sms-ping-1.8.0-sources.jar: org/opennms/sms/ping/PingResponseCallback.java <==
/*
 * This file is part of the OpenNMS(R) Application.
 *
 * OpenNMS(R) is Copyright (C) 2007 The OpenNMS Group, Inc.  All rights reserved.
 * OpenNMS(R) is a derivative work, containing both original code, included code and modified
 * code that was published under the GNU General Public License. Copyrights for modified
 * and included code are below.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * Modifications:
 * 
 * Created August 22, 2007
 *
 * Copyright (C) 2007 The OpenNMS Group, Inc.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * For more information contact:
 *      OpenNMS Licensing       <license@opennms.org>
 *      http://www.opennms.org/
 *      http://www.opennms.com/
 */
package org.opennms.sms.ping;

import org.opennms.sms.ping.internal.PingRequest;
import org.smslib.Message;

/**
 * 
 * @author <a href="mailto:ranger@opennms.org">Ben Reed</a>
 */
public interface PingResponseCallback {

	public void handleResponse(PingRequest request, Message packet);
	public void handleTimeout(PingRequest request, Message packet);
    public void handleError(PingRequest request, Message packet, Throwable t);

}

==> sms-ping-1.8.11-sources.jar: org/opennms/sms/ping/PingResponseCallback.java <==
/*
 * This file is part of the OpenNMS(R) Application.
 *
 * OpenNMS(R) is Copyright (C) 2007 The OpenNMS Group, Inc.  All rights reserved.
 * OpenNMS(R) is a derivative work, containing both original code, included code and modified
 * code that was published under the GNU General Public License. Copyrights for modified
 * and included code are below.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * Modifications:
 * 
 * Created August 22, 2007
 *
 * Copyright (C) 2007 The OpenNMS Group, Inc.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * For more information contact:
 *      OpenNMS Licensing       <license@opennms.org>
 *      http://www.opennms.org/
 *      http://www.opennms.com/
 */
package org.opennms.sms.ping;

import org.opennms.sms.ping.internal.PingRequest;
import org.smslib.Message;

/**
 * <p>PingResponseCallback interface.</p>
 *
 * @author <a href="mailto:ranger@opennms.org">Ben Reed</a>
 * @version $Id: $
 */
public interface PingResponseCallback {

	/**
	 * <p>handleResponse</p>
	 *
	 * @param request a {@link org.opennms.sms.ping.internal.PingRequest} object.
	 * @param packet a {@link org.smslib.Message} object.
	 */
	public void handleResponse(PingRequest request, Message packet);
	/**
	 * <p>handleTimeout</p>
	 *
	 * @param request a {@link org.opennms.sms.ping.internal.PingRequest} object.
	 * @param packet a {@link org.smslib.Message} object.
	 */
	public void handleTimeout(PingRequest request, Message packet);
    /**
     * <p>handleError</p>
     *
     * @param request a {@link org.opennms.sms.ping.internal.PingRequest} object.
     * @param packet a {@link org.smslib.Message} object.
     * @param t a {@link java.lang.Throwable} object.
     */
    public void handleError(PingRequest request, Message packet, Throwable t);

}
